# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['agilicus',
 'agilicus.agilicus_api',
 'agilicus.agilicus_api.api',
 'agilicus.agilicus_api.apis',
 'agilicus.agilicus_api.model',
 'agilicus.agilicus_api.models',
 'agilicus.agilicus_api.test',
 'agilicus.examples',
 'agilicus.output',
 'agilicus.tests']

package_data = \
{'': ['*'],
 'agilicus': ['.openapi-generator/*'],
 'agilicus.agilicus_api': ['docs/*']}

install_requires = \
['PyJWT>=2.6.0,<3.0.0',
 'certifi>=14.05.14',
 'click>=8.0.0,<9.0.0',
 'colorama>=0.4.3,<0.5.0',
 'cryptography>=39.0.0',
 'ipapi==1.0.4',
 'keyring>=23.0.0',
 'keyrings.alt>=4.2.0,<5.0.0',
 'oauth2client>=4.1.3,<4.2.0',
 'paho-mqtt>=1.6.1,<2.0.0',
 'prettytable>=0.7.2,<0.8.0',
 'python_dateutil>2.5.3',
 'pyyaml==5.4.1',
 'requests>=2.23.0,<3.0.0',
 'six>=1.14.0,<2.0.0',
 'xdg>=5.1.1,<6.0.0']

extras_require = \
{'billing': ['stripe>=2.60.0,<3.0.0', 'prometheus_client==0.11.0']}

entry_points = \
{'console_scripts': ['agilicus-cli = agilicus.main:main']}

setup_kwargs = {
    'name': 'agilicus',
    'version': '1.178.1',
    'description': 'Agilicus SDK',
    'long_description': '## Agilicus SDK (Python)\n\nThe [Agilicus Platform](https://www.agilicus.com/) [API](https://www.agilicus.com/api).\nis defined using [OpenAPI 3.0](https://github.com/OAI/OpenAPI-Specification),\nand may be used from any language. This allows configuration of our Zero-Trust Network Access cloud native platform\nusing REST. You can see the API specification [online](https://www.agilicus.com/api).\n\nThis package provides a Python SDK, class library interfaces for use in\naccessing individual collections. In addition it provides a command-line-interface (CLI)\nfor interactive use.\n\nRead the class-library documentation [online](https://www.agilicus.com/api/)\n\n[Samples](https://git.agilicus.com/pub/samples) shows various examples of this code in use.\n\nGenerally you may install this from [pypi](https://pypi.org/project/agilicus/) as:\n\n```\npip install --upgrade agilicus\n```\n\nYou may wish to add bash completion by adding this to your ~/.bashrc:\n\n```\neval "$(_AGILICUS_CLI_COMPLETE=source agilicus-cli)"\n```\n\n## Example: List users\nThe below python code will show the same output as the CLI command:\n`agilicus-cli --issuer https://auth.dbt.agilicus.cloud list-users`\n\n```\nimport agilicus\nimport argparse\nimport sys\n\nscopes = agilicus.scopes.DEFAULT_SCOPES\n\nparser = argparse.ArgumentParser(description="update-user")\nparser.add_argument("--auth-doc", type=str)\nparser.add_argument("--issuer", type=str)\nparser.add_argument("--email", type=str)\nparser.add_argument("--disable-user", type=bool, default=None)\nargs = parser.parse_args()\n\nif not args.auth_doc and not args.issuer:\n    print("error: specify either an --auth-doc or --issuer")\n    sys.exit(1)\n\nif not args.email:\n    print("error: specify an email to search for a user")\n    sys.exit(1)\n\napi = agilicus.GetClient(\n    agilicus_scopes=scopes, issuer=args.issuer, authentication_document=args.auth_doc\n)\n\nusers = api.users.list_users(org_id=api.default_org_id, email=args.email)\nif len(users.users) != 1:\n    print(f"error: failed to find user with email: {args.email}")\n    sys.exit(1)\n\nuser = users.users[0]\n\nif args.disable_user is not None:\n    user.enabled = args.disable_user\n\nresult = api.users.replace_user(\n    user.id, user=user, _check_input_type=False, _host_index=0\n)\nprint(result)\n```\n',
    'author': 'Agilicus Devs',
    'author_email': 'dev@agilicus.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://www.agilicus.com/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
